import { Component } from '@angular/core';
import { IonicPage, NavController, NavParams, AlertController } from 'ionic-angular';
import { FormBuilder, Validators, FormGroup } from '@angular/forms';
import { TwitterApiProvider } from '../../providers/twitter-api/twitter-api';

/**
 * Generated class for the WriteTweetPage page.
 *
 * See https://ionicframework.com/docs/components/#navigation for more info on
 * Ionic pages and navigation.
 */

@IonicPage()
@Component({
  selector: 'page-write-tweet',
  templateUrl: 'write-tweet.html',
})
export class WriteTweetPage {

  tweet: FormGroup;

  constructor(
    public navCtrl: NavController,
    public navParams: NavParams,
    private formBuilder: FormBuilder,
    private twitter: TwitterApiProvider,
    private alertCtrl: AlertController
  ) {
    this.tweet = this.formBuilder.group({
      text: ['', Validators.maxLength(140)],
      p2p: [false]
    });
  }

  ionViewDidLoad() {

  }

  get tweetCharProgress() {
    let progress = 1 - this.tweet.value["text"].length / 140;
    let radius = 8;
    let circumference = Math.PI * radius * 2;
    return progress * circumference;
  }

  submitTweet() {

    if (this.tweet.value.p2p) {
      this.alertCtrl.create({
        title: 'Private Mode',
        subTitle: 'Your tweet will be encrypted and send to the private network. TODO!',
        buttons: ['OK']
      }).present();
    } else {
      this.twitter.tweet(this.tweet.value["text"]);
    }

    this.navCtrl.pop();
  }

}
